==> nautilus-cd-burner-2.12.0.tar.bz2: nautilus-cd-burner-2.12.0/list_cddrives.c <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
 * 
 * Copyright (C) 2003-2004 Bastien Nocera <hadess@hadess.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Bastien Nocera <hadess@hadess.net>
 *
 */

#include <glib.h>
#include <string.h>
#include "nautilus-burn-drive.h"

static char *
add_desc (char       *string,
	  const char *addition)
{
	char *new;

	if (strcmp (string, "") == 0) {
		new = g_strdup_printf ("%s", addition);
	} else {
		new = g_strdup_printf ("%s/%s", string, addition);
	}
	g_free (string);
	return new;
}

static char *
drive_type (int type)
{
	char *string;

	string = g_strdup ("");
	if (type & NAUTILUS_BURN_DRIVE_TYPE_FILE) {
		string = add_desc (string, "File");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_CD_RECORDER) {
		string = add_desc (string, "CD Recorder");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_CDRW_RECORDER) {
		string = add_desc (string, "CD ReWritable");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RAM_RECORDER) {
		string = add_desc (string, "DVD-RAM");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RW_RECORDER) {
		string = add_desc (string, "DVD-RW");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_PLUS_R_RECORDER) {
		string = add_desc (string, "DVD+R");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_PLUS_RW_RECORDER) {
		string = add_desc (string, "DVD+RW");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_CD_DRIVE) {
		string = add_desc (string, "CD Drive");
	}
	if (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_DRIVE) {
		string = add_desc (string, "DVD Drive");
	}

	return string;
}

static void
list_drives (void)
{
	GList             *drives, *l;
	NautilusBurnDrive *drive;

	drives = nautilus_burn_drive_get_list (FALSE, FALSE);

	for (l = drives; l != NULL; l = l->next) {
		char       *type_str;
		const char *media;
		int         media_type;
		gboolean    is_rewritable;
		gboolean    is_blank;
		gboolean    has_data;
		gboolean    has_audio;
		gboolean    door_is_open;
		gint64      size;

		drive = l->data;
		type_str = drive_type (drive->type);
		media_type = nautilus_burn_drive_get_media_type_full (drive,
								      &is_rewritable,
								      &is_blank,
								      &has_data,
								      &has_audio);
		media = nautilus_burn_drive_media_type_get_string (media_type);

		door_is_open = nautilus_burn_drive_door_is_open (drive);

		g_print ("name: %s device: %s max_speed_read: %d\n",
			 drive->display_name,
			 drive->device,
			 drive->max_speed_read);
		g_print ("door: %s\n", door_is_open ? "open" : "closed");
		g_print ("type: %s\n", type_str);
		g_print ("media type: %s%s%s%s%s\n",
			 media,
			 is_rewritable ? " (rewritable)" : "",
			 is_blank ? " (blank)" : "",
			 has_data ? " (has-data)" : "",
			 has_audio ? " (has-audio)" : "");

		size = nautilus_burn_drive_get_media_size (drive);
		if (size >= 0) {
			g_print ("media size: %0.2f MiB", (float) size / 1024 / 1024);

			if (media_type == NAUTILUS_BURN_MEDIA_TYPE_CD
			    || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDR
			    || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDRW) {
				g_print (" approx. or %d mins %d secs\n",
					 NAUTILUS_BURN_DRIVE_SIZE_TO_TIME (size) / 60,
					 NAUTILUS_BURN_DRIVE_SIZE_TO_TIME (size) % 60);
			} else {
				g_print ("\n");
			}
		} else {
			g_print ("media size: Could not be determined\n");
		}

		g_print ("CD-Recorder/SCSI devices only: max_speed_write: %d"
			 " id: %s\n", drive->max_speed_write,
			 drive->cdrecord_id);
		g_print ("\n");

		g_free (type_str);
		nautilus_burn_drive_free (drive);
	}

	g_list_free (drives);
}

int main (int argc, char **argv)
{
	list_drives ();

	return 0;
}

==> nautilus-cd-burner-2.13.1.tar.bz2: nautilus-cd-burner-2.13.1/list_cddrives.c <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
 * 
 * Copyright (C) 2003-2004 Bastien Nocera <hadess@hadess.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Bastien Nocera <hadess@hadess.net>
 *
 */

#include <glib.h>
#include <string.h>
#include "nautilus-burn-drive.h"

static void
list_drives (void)
{
	GList             *drives, *l;
	NautilusBurnDrive *drive;

	drives = nautilus_burn_drive_get_list (FALSE, FALSE);

	for (l = drives; l != NULL; l = l->next) {
		char       *type_str;
		const char *media;
		int         media_type;
		gboolean    is_rewritable;
		gboolean    is_blank;
		gboolean    has_data;
		gboolean    has_audio;
		gboolean    door_is_open;
		gint64      size;

		drive = l->data;
		type_str = nautilus_burn_drive_get_supported_media_string (drive, FALSE);
		media_type = nautilus_burn_drive_get_media_type_full (drive,
								      &is_rewritable,
								      &is_blank,
								      &has_data,
								      &has_audio);
		media = nautilus_burn_drive_media_type_get_string (media_type);

		door_is_open = nautilus_burn_drive_door_is_open (drive);

		g_print ("name: %s device: %s max_speed_read: %d\n",
			 drive->display_name,
			 drive->device,
			 drive->max_speed_read);
		g_print ("door: %s\n", door_is_open ? "open" : "closed");
		g_print ("type: %s\n", type_str);
		g_print ("media type: %s%s%s%s%s\n",
			 media,
			 is_rewritable ? " (rewritable)" : "",
			 is_blank ? " (blank)" : "",
			 has_data ? " (has-data)" : "",
			 has_audio ? " (has-audio)" : "");

		size = nautilus_burn_drive_get_media_size (drive);
		if (size >= 0) {
			g_print ("media size: %0.2f MiB", (float) size / 1024 / 1024);

			if (media_type == NAUTILUS_BURN_MEDIA_TYPE_CD
			    || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDR
			    || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDRW) {
				g_print (" approx. or %d mins %d secs\n",
					 NAUTILUS_BURN_DRIVE_SIZE_TO_TIME (size) / 60,
					 NAUTILUS_BURN_DRIVE_SIZE_TO_TIME (size) % 60);
			} else {
				g_print ("\n");
			}
		} else {
			g_print ("media size: Could not be determined\n");
		}

		g_print ("CD-Recorder/SCSI devices only: max_speed_write: %d"
			 " id: %s\n", drive->max_speed_write,
			 drive->cdrecord_id);
		g_print ("\n");

		g_free (type_str);
		nautilus_burn_drive_unref (drive);
	}

	g_list_free (drives);
}

int main (int argc, char **argv)
{
	g_type_init ();
	list_drives ();

	return 0;
}
